@@ -108,6 +108,8 @@ class RingBuilder(object):
         # a device overrides this behavior as it's assumed that's only
         # done because of device failure.
         self._last_part_moves = None
+        # _part_moved_bitmap record parts have been moved
+        self._part_moved_bitmap = None
         # _last_part_moves_epoch indicates the time the offsets in
         # _last_part_moves is based on.
         self._last_part_moves_epoch = 0
@@ -125,6 +127,19 @@ class RingBuilder(object):
             # silence "no handler for X" error messages
             self.logger.addHandler(NullHandler())
 
+    def _set_part_moved(self, part):
+        self._last_part_moves[part] = 0
+        byte, bit = divmod(part, 8)
+        self._part_moved_bitmap[byte] |= (128 >> bit)
+
+    def _has_part_moved(self, part):
+        byte, bit = divmod(part, 8)
+        return bool(self._part_moved_bitmap[byte] & (128 >> bit))
+
+    def _can_part_move(self, part):
+        return (self._last_part_moves[part] >= self.min_part_hours and
+                not self._has_part_moved(part))
+
     @contextmanager
     def debug(self):
         """
@@ -437,6 +452,7 @@ class RingBuilder(object):
         if self._last_part_moves is None:
             self.logger.debug("New builder; performing initial balance")
             self._last_part_moves = array('B', itertools.repeat(0, self.parts))
+        self._part_moved_bitmap = bytearray(max(2 ** (self.part_power - 3), 1))
         self._update_last_part_moves()
 
         replica_plan = self._build_replica_plan()
@@ -801,14 +817,14 @@ class RingBuilder(object):
                 return
             to_place = defaultdict(int)
             for t in sub_tiers:
-                to_place[t] = int(math.floor(
-                    replica_plan[t]['target'] * self.parts))
+                to_place[t] = min(parts, int(math.floor(
+                    replica_plan[t]['target'] * self.parts)))
                 parts -= to_place[t]
 
             # if there's some parts left over, just throw 'em about
             sub_tier_gen = itertools.cycle(sorted(
                 sub_tiers, key=lambda t: replica_plan[t]['target']))
-            while parts:
+            while parts > 0:
                 t = next(sub_tier_gen)
                 to_place[t] += 1
                 parts -= 1
@@ -876,7 +892,7 @@ class RingBuilder(object):
                     dev_id = self._replica2part2dev[replica][part]
                     if dev_id in dev_ids:
                         self._replica2part2dev[replica][part] = NONE_DEV
-                        self._last_part_moves[part] = 0
+                        self._set_part_moved(part)
                         assign_parts[part].append(replica)
                         self.logger.debug(
                             "Gathered %d/%d from dev %d [dev removed]",
@@ -964,7 +980,7 @@ class RingBuilder(object):
         # Now we gather partitions that are "at risk" because they aren't
         # currently sufficient spread out across the cluster.
         for part in range(self.parts):
-            if self._last_part_moves[part] < self.min_part_hours:
+            if (not self._can_part_move(part)):
                 continue
             # First, add up the count of replicas at each tier for each
             # partition.
@@ -996,7 +1012,7 @@ class RingBuilder(object):
                 # has more than one replica of a part assigned to it - which
                 # would have only been possible on rings built with an older
                 # version of the code
-                if (self._last_part_moves[part] < self.min_part_hours and
+                if (not self._can_part_move(part) and
                         not replicas_at_tier[dev['tiers'][-1]] > 1):
                     continue
                 dev['parts_wanted'] += 1
@@ -1008,7 +1024,7 @@ class RingBuilder(object):
                 self._replica2part2dev[replica][part] = NONE_DEV
                 for tier in dev['tiers']:
                     replicas_at_tier[tier] -= 1
-                self._last_part_moves[part] = 0
+                self._set_part_moved(part)
 
     def _gather_parts_for_balance_can_disperse(self, assign_parts, start,
                                                replica_plan):
@@ -1025,7 +1041,7 @@ class RingBuilder(object):
         # they have more partitions than their parts_wanted.
         for offset in range(self.parts):
             part = (start + offset) % self.parts
-            if self._last_part_moves[part] < self.min_part_hours:
+            if (not self._can_part_move(part)):
                 continue
             # For each part we'll look at the devices holding those parts and
             # see if any are overweight, keeping track of replicas_at_tier as
@@ -1048,7 +1064,7 @@ class RingBuilder(object):
             overweight_dev_replica.sort(
                 key=lambda dr: dr[0]['parts_wanted'])
             for dev, replica in overweight_dev_replica:
-                if self._last_part_moves[part] < self.min_part_hours:
+                if (not self._can_part_move(part)):
                     break
                 if any(replica_plan[tier]['min'] <=
                        replicas_at_tier[tier] <
@@ -1067,7 +1083,7 @@ class RingBuilder(object):
                 self._replica2part2dev[replica][part] = NONE_DEV
                 for tier in dev['tiers']:
                     replicas_at_tier[tier] -= 1
-                self._last_part_moves[part] = 0
+                self._set_part_moved(part)
 
     def _gather_parts_for_balance(self, assign_parts, replica_plan):
         """
@@ -1107,7 +1123,7 @@ class RingBuilder(object):
         """
         for offset in range(self.parts):
             part = (start + offset) % self.parts
-            if self._last_part_moves[part] < self.min_part_hours:
+            if (not self._can_part_move(part)):
                 continue
             overweight_dev_replica = []
             for replica in self._replicas_for_part(part):
@@ -1124,7 +1140,7 @@ class RingBuilder(object):
             overweight_dev_replica.sort(
                 key=lambda dr: dr[0]['parts_wanted'])
             for dev, replica in overweight_dev_replica:
-                if self._last_part_moves[part] < self.min_part_hours:
+                if (not self._can_part_move(part)):
                     break
                 # this is the most overweight_device holding a replica of this
                 # part we don't know where it's going to end up - but we'll
@@ -1136,7 +1152,7 @@ class RingBuilder(object):
                     "Gathered %d/%d from dev %d [weight forced]",
                     part, replica, dev['id'])
                 self._replica2part2dev[replica][part] = NONE_DEV
-                self._last_part_moves[part] = 0
+                self._set_part_moved(part)
 
     def _reassign_parts(self, reassign_parts, replica_plan):
         """
