@@ -19,7 +19,7 @@ import unittest2
 import json
 from uuid import uuid4
 from unittest2 import SkipTest
-from string import letters
+from string import ascii_letters
 
 from six.moves import range
 from swift.common.middleware.acl import format_acl
@@ -98,11 +98,11 @@ class TestAccount(unittest2.TestCase):
         resp = retry(head)
         resp.read()
         self.assertIn(resp.status, (200, 204))
-        self.assertEqual(resp.getheader('x-account-meta-test'), None)
+        self.assertIsNone(resp.getheader('x-account-meta-test'))
         resp = retry(get)
         resp.read()
         self.assertIn(resp.status, (200, 204))
-        self.assertEqual(resp.getheader('x-account-meta-test'), None)
+        self.assertIsNone(resp.getheader('x-account-meta-test'))
         resp = retry(post, 'Value')
         resp.read()
         self.assertEqual(resp.status, 204)
@@ -127,7 +127,7 @@ class TestAccount(unittest2.TestCase):
         # needs to be an acceptable header size
         num_keys = 8
         max_key_size = load_constraint('max_header_size') / num_keys
-        acl = {'admin': [c * max_key_size for c in letters[:num_keys]]}
+        acl = {'admin': [c * max_key_size for c in ascii_letters[:num_keys]]}
         headers = {'x-account-access-control': format_acl(
             version=2, acl_dict=acl)}
         resp = retry(post, headers=headers, use_account=1)
@@ -135,7 +135,8 @@ class TestAccount(unittest2.TestCase):
         self.assertEqual(resp.status, 400)
 
         # and again a touch smaller
-        acl = {'admin': [c * max_key_size for c in letters[:num_keys - 1]]}
+        acl = {'admin': [c * max_key_size for c
+                         in ascii_letters[:num_keys - 1]]}
         headers = {'x-account-access-control': format_acl(
             version=2, acl_dict=acl)}
         resp = retry(post, headers=headers, use_account=1)
@@ -163,7 +164,7 @@ class TestAccount(unittest2.TestCase):
         resp = retry(post, headers, use_account=1)
         resp.read()
         self.assertEqual(resp.status, 400)
-        self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+        self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
     @requires_acls
     def test_invalid_acl_values(self):
@@ -179,7 +180,7 @@ class TestAccount(unittest2.TestCase):
         resp = retry(post, headers=headers, use_account=1)
         resp.read()
         self.assertEqual(resp.status, 400)
-        self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+        self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
     @requires_acls
     def test_read_only_acl(self):
@@ -214,7 +215,7 @@ class TestAccount(unittest2.TestCase):
         resp.read()
         self.assertIn(resp.status, (200, 204))
         # but not acls
-        self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+        self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
         # read-only can not write metadata
         headers = {'x-account-meta-test': 'value'}
@@ -265,7 +266,7 @@ class TestAccount(unittest2.TestCase):
         resp.read()
         self.assertIn(resp.status, (200, 204))
         # but not acls
-        self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+        self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
         # read-write can not write account metadata
         headers = {'x-account-meta-test': 'value'}
@@ -367,12 +368,11 @@ class TestAccount(unittest2.TestCase):
         # read-only tester3 can read account metadata
         resp = retry(get, use_account=3)
         resp.read()
-        self.assertTrue(
-            resp.status in (200, 204),
-            'Expected status in (200, 204), got %s' % resp.status)
+        self.assertIn(resp.status, (200, 204),
+                      'Expected status in (200, 204), got %s' % resp.status)
         self.assertEqual(resp.getheader('X-Account-Meta-Test'), value)
         # but not temp-url-key
-        self.assertEqual(resp.getheader('X-Account-Meta-Temp-Url-Key'), None)
+        self.assertIsNone(resp.getheader('X-Account-Meta-Temp-Url-Key'))
 
         # grant read-write access to tester3
         acl_user = tf.swift_test_user[2]
@@ -386,12 +386,11 @@ class TestAccount(unittest2.TestCase):
         # read-write tester3 can read account metadata
         resp = retry(get, use_account=3)
         resp.read()
-        self.assertTrue(
-            resp.status in (200, 204),
-            'Expected status in (200, 204), got %s' % resp.status)
+        self.assertIn(resp.status, (200, 204),
+                      'Expected status in (200, 204), got %s' % resp.status)
         self.assertEqual(resp.getheader('X-Account-Meta-Test'), value)
         # but not temp-url-key
-        self.assertEqual(resp.getheader('X-Account-Meta-Temp-Url-Key'), None)
+        self.assertIsNone(resp.getheader('X-Account-Meta-Temp-Url-Key'))
 
         # grant admin access to tester3
         acl_user = tf.swift_test_user[2]
@@ -405,9 +404,8 @@ class TestAccount(unittest2.TestCase):
         # admin tester3 can read account metadata
         resp = retry(get, use_account=3)
         resp.read()
-        self.assertTrue(
-            resp.status in (200, 204),
-            'Expected status in (200, 204), got %s' % resp.status)
+        self.assertIn(resp.status, (200, 204),
+                      'Expected status in (200, 204), got %s' % resp.status)
         self.assertEqual(resp.getheader('X-Account-Meta-Test'), value)
         # including temp-url-key
         self.assertEqual(resp.getheader('X-Account-Meta-Temp-Url-Key'),
@@ -423,9 +421,8 @@ class TestAccount(unittest2.TestCase):
         self.assertEqual(resp.status, 204)
         resp = retry(get, use_account=3)
         resp.read()
-        self.assertTrue(
-            resp.status in (200, 204),
-            'Expected status in (200, 204), got %s' % resp.status)
+        self.assertIn(resp.status, (200, 204),
+                      'Expected status in (200, 204), got %s' % resp.status)
         self.assertEqual(resp.getheader('X-Account-Meta-Temp-Url-Key'),
                          secret)
 
@@ -463,13 +460,13 @@ class TestAccount(unittest2.TestCase):
                          use_account=1)
             resp.read()
             self.assertEqual(resp.status, 204)
-            self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+            self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
             # User1 can GET their own empty account
             resp = retry(get, use_account=1)
             resp.read()
             self.assertEqual(resp.status // 100, 2)
-            self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+            self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
             # User2 can't GET User1's account
             resp = retry(get, use_account=2, url_account=1)
@@ -513,7 +510,7 @@ class TestAccount(unittest2.TestCase):
             resp = retry(head, use_account=2, url_account=1)
             resp.read()
             self.assertEqual(resp.status, 204)
-            self.assertEqual(resp.getheader('x-account-access-control'), None)
+            self.assertIsNone(resp.getheader('x-account-access-control'))
 
             # User2 can PUT and DELETE a container
             resp = retry(put, use_account=2, url_account=1,
@@ -538,7 +535,7 @@ class TestAccount(unittest2.TestCase):
             resp = retry(head, use_account=2, url_account=1)
             resp.read()
             self.assertEqual(resp.status, 204)
-            self.assertEqual(resp.getheader('x-account-access-control'), None)
+            self.assertIsNone(resp.getheader('x-account-access-control'))
 
             # User2 can't PUT a container
             resp = retry(put, use_account=2, url_account=1,
@@ -576,13 +573,13 @@ class TestAccount(unittest2.TestCase):
             resp = retry(post, headers={'X-Account-Access-Control': '{}'})
             resp.read()
             self.assertEqual(resp.status, 204)
-            self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+            self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
             # User1 can GET their own empty account
             resp = retry(get)
             resp.read()
             self.assertEqual(resp.status // 100, 2)
-            self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+            self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
             # User1 can POST non-empty data
             acl_json = '{"admin":["bob"]}'
@@ -635,13 +632,13 @@ class TestAccount(unittest2.TestCase):
             resp = retry(post, headers={'X-Account-Access-Control': '{}'})
             resp.read()
             self.assertEqual(resp.status, 204)
-            self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+            self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
             # User1 can GET their own empty account
             resp = retry(get)
             resp.read()
             self.assertEqual(resp.status // 100, 2)
-            self.assertEqual(resp.getheader('X-Account-Access-Control'), None)
+            self.assertIsNone(resp.getheader('X-Account-Access-Control'))
 
             # User1 can POST non-empty data
             acl_json = '{"admin":["bob"]}'
